
<h1 align="center"><img src="images/logo.png" style="width:140px; height:auto"></h1>
<p align="center">Keep-cli is a cli Google Keep client. You can add, delete, and manage your Google Keep notes.</p>

<p align="center">
<a href="https://badge.fury.io/py/keep-cli"><img src="https://badge.fury.io/py/keep-cli.svg" alt="PyPI version" height="18"></a>
<a href="./LICENSE.md"><img src="https://img.shields.io/badge/License-MIT-yellow.svg" alt="MIT License" height="18"></a>
<img src="https://img.shields.io/github/stars/zack-ashen/keep-cli" alt="Github Stars" height="18">


</p>

![alt text](images/screenshot.png "Demo")

## Setup

### Installation

#### PIP (easiest)
```sh
pip install keep-cli
```

#### Arch Linux (AUR)
```sh
yay -S keep-cli-git
```

### Configuration
In order to make a note you must have the `$EDITOR` environment variable set to a text editor.

## Usage

### Run keep-cli visually:
```sh
keep-cli
```
#### Skip the intro animation (quick mode):
```sh
keep-cli --quick
```
#### Make a list or note:
For a note:
```sh
keep-cli --note
```
For a list:
```sh
keep-cli --list
```
## More Info
<p> This project is still under heavy development, so if you would like to help out feel free to reach out. </p>
